%**************This Module assume the radar incident angle is 0 to 80 deg**********************%

%hight of radar
AH = 0.5;
MQ = AH;
%AM = HQ;

%define maximum radar incident angle is 80 degree
in_angle = deg2rad(80);
%define the maximum distance
HK = AH * tan(in_angle);   

Grid_nr = 256;

%divide the area into 1024 (64*64) grids
%point Q is the center point of a grid
P_pos = HK/(Grid_nr*2);%11m/64 Point P z, P is the center of the grid


%we set the speed v = 1 km/h for exsemple
v = 70;
%convert the speed unit fromm km/h to m/s
v = v*5/18;

ALPHA_MATRIX = zeros(Grid_nr,Grid_nr);%divided the ellipse into 1024 grids
BETA_MATRIX = zeros(Grid_nr,Grid_nr);%divided the ellipse into 1024 grids

%Define Sigma0 Matrix, each value stands for sigma0 of each grid
Sigma0_MATRIX = zeros(Grid_nr,Grid_nr);

%Define RCS
RCS_MATRIX = zeros(Grid_nr,Grid_nr);
% store all the gain from all the grids
G_MATRIX = zeros(Grid_nr,Grid_nr);

lamda = (3.0*10^8)/(24.1 *10^9);% lamda=c/f
%total transmitting power is 5mW
Pt = 0.005;

Pr_MATRIX = zeros(Grid_nr,Grid_nr);
Fd_MATRIX = zeros(Grid_nr,Grid_nr);

Angle_H_MATRIX = zeros(Grid_nr,Grid_nr);
Angle_V_MATRIX = zeros(Grid_nr,Grid_nr);

for i =0:Grid_nr-1
    HQ = P_pos*(2*i+1);
    for j = 0:Grid_nr-1       
        PQ = P_pos*(2*j+1);
        AP = sqrt(AH^2+HQ^2+PQ^2);%distance from radar to the ground
        MP = sqrt(MQ^2+PQ^2);
        
        beta = rad2deg(acos(AH/AP));
        alpha = rad2deg(acos((HQ^2+AP^2-MP^2)/(2*HQ*AP)));
        %define angle QAP, the angle between radar beam horizontal 
        Angle_QAP = rad2deg(asin(PQ/AP));
        %find Gain
        Angle_H = Angle_QAP;%angle in horizontal plan
        Angle_H_MATRIX(j+1,i+1) = Angle_H;
        Angle_V = 90 - beta;%angle in vertical plan
        Angle_V_MATRIX(j+1,i+1) = Angle_V;
        %Call function findG
        G = findG(Angle_H, Angle_V);
        G_MATRIX(j+1, i+1) = G;
        
        ALPHA_MATRIX(j+1,i+1)= alpha;
        BETA_MATRIX(j+1,i+1)= beta;
        %Call function findS0
        Sigma0 = findS0(beta);
        Sigma0_MATRIX(j+1,i+1) = Sigma0;%Store Sigma0 in Matrix
        
        %Find RCS = Area * Sigma_0
        RCS = (2*HQ)^2*Sigma0;
        %Store RCS in Matrix
        RCS_MATRIX(j+1, i+1) = RCS;
        
        Pr = G^2*lamda^2*Pt*RCS/((4*pi)^3*AP^4);
        Pr_MATRIX(j+1,i+1)=Pr;
        
        fd= 2*80*v*(HQ^2+AP^2-MP^2)/(2*HQ*AP);%f/c = 80
        Fd_MATRIX(j+1,i+1)=fd;
        
    end
end
Pr_MATRIX = Pr_MATRIX * 2;

%----------------------Find the Radar singal function--------------------%
%change matrix Fd_MATRIX to one column array.
Fd_array = Fd_MATRIX(:); %1024 X 1
%Amplitude of reflected signal
Amp_MATRIX = sqrt(Pr_MATRIX);
%change matrix Amp_MATRIX to one row array
Amp_array = Amp_MATRIX(:)';%1 X 1024
%find max doppler frequency
Fd_max = max(Fd_array);
%sample frequency, fs>=2fd_max
%fs = 1000;
fs = 5 * Fd_max;
%sample time delta t
D_t = 1/fs;
t = 0:D_t:(2^11-1)*D_t; %sample 2048 by changing the 2^10 to 2^11

%define phi
Phi_array = 2*pi*rand(Grid_nr^2,1);
Phi_array = Phi_array(:)';
%define complex number i
i = sqrt(-1);
%Define amplitude with PHI
AmP_array = Amp_array.*exp(i*Phi_array);
%The Radar signal
x_t = Amp_array*exp(i*2*pi*Fd_array*t);%matrix multiplify

%take 1024 point in the middle
x_t = x_t(1025:2048);
t=t(1025:2048);

figure(1);
plot(t,x_t);
%xlabel('Sample time Unkonwn units');
ylabel('Amplitude');
title('Received Signal');
%----------------------END Find the Radar singal function-----------------%
nfft = 1024;

%------------------------------- AR module Method-----------------------------%
Order = 10;
figure(2);
pyulear(x_t,Order,nfft,fs);
%------------------------------- AR module -----------------------------%