%**************This Module assume the radar incident angle is 0 to 80 deg**********************%

%hight of radar
AH = 1.5;
MQ = AH;
%AM = HQ;

%define maximum radar incident angle is 80 degree
in_angle = deg2rad(80);
%define the maximum distance
HK = AH * tan(in_angle);   

Grid_nr = 128;
%divide the area into 1024 (64*64) grids
%point Q is the center point of a grid
P_pos = HK/(Grid_nr*2);%11m/64 Point P z, P is the center of the grid


%we set the speed v = 1 km/h for exsemple
v = 170;
%convert the speed unit fromm km/h to m/s
v = v*5/18;

ALPHA_MATRIX = zeros(Grid_nr,Grid_nr);%divided the ellipse into 1024 grids
BETA_MATRIX = zeros(Grid_nr,Grid_nr);%divided the ellipse into 1024 grids

%Define Sigma0 Matrix, each value stands for sigma0 of each grid
Sigma0_MATRIX = zeros(Grid_nr,Grid_nr);

%Define RCS
RCS_MATRIX = zeros(Grid_nr,Grid_nr);
% store all the gain from all the grids
G_MATRIX = zeros(Grid_nr,Grid_nr);

lamda = (3.0*10^8)/(24.1 *10^9);% lamda=c/f
%total transmitting power is 5mW
Pt = 0.005;

Pr_MATRIX = zeros(Grid_nr,Grid_nr);
Fd_MATRIX = zeros(Grid_nr,Grid_nr);

Angle_H_MATRIX = zeros(Grid_nr,Grid_nr);
Angle_V_MATRIX = zeros(Grid_nr,Grid_nr);

for i =0:Grid_nr-1
    HQ = P_pos*(2*i+1);
    for j = 0:Grid_nr-1       
        PQ = P_pos*(2*j+1);
        AP = sqrt(AH^2+HQ^2+PQ^2);%distance from radar to the ground
        MP = sqrt(MQ^2+PQ^2);
        
        beta = rad2deg(acos(AH/AP));
        alpha = rad2deg(acos((HQ^2+AP^2-MP^2)/(2*HQ*AP)));
        ALPHA_MATRIX(j+1,i+1) = alpha;
        %define angle QAP, the angle between radar beam horizontal 
        Angle_QAP = rad2deg(asin(PQ/AP));
        %find Gain
        Angle_H = Angle_QAP;%angle in horizontal plan
        Angle_H_MATRIX(j+1,i+1) = Angle_H;
        Angle_V = 90 - beta;%angle in vertical plan
        Angle_V_MATRIX(j+1,i+1) = Angle_V;
        %Call function findG
        G = findG(Angle_H, Angle_V);
        G_MATRIX(j+1, i+1) = G;
        
        ALPHA_MATRIX(j+1,i+1)= alpha;
        BETA_MATRIX(j+1,i+1)= beta;
        %Call function findS0
        Sigma0 = findS0(beta);
        Sigma0_MATRIX(j+1,i+1) = Sigma0;%Store Sigma0 in Matrix
        
        %Find RCS = Area * Sigma_0
        RCS = (2*HQ)^2*Sigma0;
        %Store RCS in Matrix
        RCS_MATRIX(j+1, i+1) = RCS;
        
        Pr = G^2*lamda^2*Pt*RCS/((4*pi)^3*AP^4);
        Pr_MATRIX(j+1,i+1)=Pr;
        
        fd= 2*80*v*(HQ^2+AP^2-MP^2)/(2*HQ*AP);%f/c = 80
        Fd_MATRIX(j+1,i+1)=fd;
        
    end
end
Pr_MATRIX = Pr_MATRIX * 2;%symetric

%-------------sum all the reflected power density in the interval of bandwidth----------%
Fd_max = max(max(Fd_MATRIX));
Fd_min = min(min(Fd_MATRIX));

Sample_nr = 64;
begin = Fd_min;
bandwidth = (Fd_max-Fd_min)/Sample_nr;
Pr_sum_array = zeros(1,Sample_nr+1);% Maximum frequency is 160hz when v = 1m/s
x_axis = begin:bandwidth:Fd_max;
for N = 0:Sample_nr
    sum = 0;
    for i = 0:Grid_nr-1
        for j = 0:Grid_nr-1
            if (Fd_MATRIX(j+1,i+1)>=(begin+bandwidth*N)) && (Fd_MATRIX(j+1,i+1)<(begin +(N+1)*bandwidth))
            sum = sum + Pr_MATRIX(j+1,i+1);
            end  
        end
    end
    Pr_sum_array(1,N+1)= sum;
end 
%------------------END sum all the reflected power density in the interval of bandwidth -----%

figure(1);
plot(x_axis,10*log10(Pr_sum_array./0.001));%dBm
xlabel('Doppler frequency /Hz');
ylabel('Reflected power /dBm');
grid on;
